Module publish

Module publish 

Enums

Kind
The kind of resource being published.

Functions

publish_agent
Publishes an agent to the local filesystem git repository.
publish_function
Publishes a function to the local filesystem git repository.
publish_profile
Publishes a profile to the local filesystem git repository.
publish_swarm
Publishes a swarm to the local filesystem git repository.