Module plugin_path

Module plugin_path 

PluginPath — the (owner, repository, version) coordinate of the plugin a command is running on behalf of.

Set on crate::context::Context::plugin when the CLI executes a command that originated from a plugin’s bidirectional protocol. The three parts are threaded to nested-command subprocesses via the OBJECTIVEAI_PLUGIN_OWNER / _REPOSITORY / _VERSION env vars (see [crate::spawn::apply_config_env]).

Structs

PluginPath