functions tier dispatch.
Modules
- execute
functions executesub-tier. Standard and SwissSystem are chunk-or-id streaming leaves; their bare-nakedexecutereturnsStream<ResponseItem>and the inner stream is mapped into the tier’sResponseItemdirectly.- get
functions get— read a function definition by remote path.- list
functions list <source>— enumerate functions from a given source. Streams oneResponseItemper function. Sources:- profiles
functions profilessub-tier.- publish
functions publish— write aFullRemoteFunctionto a repository on the filesystem and return its content sha.